# SquareConnect.Payment

### Description

Represents a payment processed by the Square API.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **String** | A unique ID for the payment. | [optional] 
**created_at** | **String** | The timestamp of when the payment was created, in RFC 3339 format. | [optional] 
**updated_at** | **String** | The timestamp of when the payment was last updated, in RFC 3339 format. | [optional] 
**amount_money** | [**Money**](Money.md) | The amount processed for this payment, not including &#x60;tip_money&#x60;.  The amount is specified in the smallest denomination of the applicable currency (for example, US dollar amounts are specified in cents). For more information, see [Working with Monetary Amounts](https://developer.squareup.com/docs/build-basics/working-with-monetary-amounts). | [optional] 
**tip_money** | [**Money**](Money.md) | The amount designated as a tip.   This amount is specified in the smallest denomination of the applicable currency (for example, US dollar amounts are specified in cents). For more information, see [Working with Monetary Amounts](https://developer.squareup.com/docs/build-basics/working-with-monetary-amounts). | [optional] 
**total_money** | [**Money**](Money.md) | The total amount for the payment, including &#x60;amount_money&#x60; and &#x60;tip_money&#x60;. This amount is specified in the smallest denomination of the applicable currency (for example, US dollar amounts are specified in cents). For more information, see [Working with Monetary Amounts](https://developer.squareup.com/docs/build-basics/working-with-monetary-amounts). | [optional] 
**app_fee_money** | [**Money**](Money.md) | The amount the developer is taking as a fee for facilitating the payment on behalf of the seller. This amount is specified in the smallest denomination of the applicable currency (for example, US dollar amounts are specified in cents). For more information, see [Take Payments and Collect Fees](https://developer.squareup.com/docs/payments-api/take-payments-and-collect-fees).  The amount cannot be more than 90% of the &#x60;total_money&#x60; value. | [optional] 
**processing_fee** | [**[ProcessingFee]**](ProcessingFee.md) | The processing fees and fee adjustments assessed by Square for this payment. | [optional] 
**refunded_money** | [**Money**](Money.md) | The total amount of the payment refunded to date.   This amount is specified in the smallest denomination of the applicable currency (for example, US dollar amounts are specified in cents). | [optional] 
**status** | **String** | Indicates whether the payment is APPROVED, COMPLETED, CANCELED, or FAILED. | [optional] 
**delay_duration** | **String** | The duration of time after the payment&#39;s creation when Square automatically applies the &#x60;delay_action&#x60; to the payment. This automatic &#x60;delay_action&#x60; applies only to payments that do not reach a terminal state (COMPLETED, CANCELED, or FAILED) before the &#x60;delay_duration&#x60; time period.  This field is specified as a time duration, in RFC 3339 format.  Notes: This feature is only supported for card payments.  Default:  - Card-present payments: \&quot;PT36H\&quot; (36 hours) from the creation time. - Card-not-present payments: \&quot;P7D\&quot; (7 days) from the creation time. | [optional] [beta]
**delay_action** | **String** | The action to be applied to the payment when the &#x60;delay_duration&#x60; has elapsed. This field is read-only.  Current values include &#x60;CANCEL&#x60;. | [optional] [beta]
**delayed_until** | **String** | The read-only timestamp of when the &#x60;delay_action&#x60; is automatically applied, in RFC 3339 format.  Note that this field is calculated by summing the payment&#39;s &#x60;delay_duration&#x60; and &#x60;created_at&#x60; fields. The &#x60;created_at&#x60; field is generated by Square and might not exactly match the time on your local machine. | [optional] [beta]
**source_type** | **String** | The source type for this payment.  Current values include &#x60;CARD&#x60;. | [optional] 
**card_details** | [**CardPaymentDetails**](CardPaymentDetails.md) | Non-confidential details about the source. The details are only populated if the &#x60;source_type&#x60; is &#x60;CARD&#x60;. | [optional] 
**location_id** | **String** | The ID of the location associated with the payment. | [optional] 
**order_id** | **String** | The ID of the order associated with the payment. | [optional] 
**reference_id** | **String** | An optional ID that associates the payment with an entity in another system. | [optional] 
**customer_id** | **String** | The &#x60;Customer&#x60; ID of the customer associated with the payment. | [optional] 
**employee_id** | **String** | An optional ID of the employee associated with taking the payment. | [optional] 
**refund_ids** | **[String]** | A list of &#x60;refund_id&#x60;s identifying refunds for the payment. | [optional] 
**risk_evaluation** | [**RiskEvaluation**](RiskEvaluation.md) | Provides information about the risk associated with the payment, as determined by Square. This field is present for payments to sellers that have opted in to receive risk evaluations. | [optional] 
**buyer_email_address** | **String** | The buyer&#39;s email address. | [optional] 
**billing_address** | [**Address**](Address.md) | The buyer&#39;s billing address. | [optional] 
**shipping_address** | [**Address**](Address.md) | The buyer&#39;s shipping address. | [optional] 
**note** | **String** | An optional note to include when creating a payment. | [optional] 
**statement_description_identifier** | **String** | Additional payment information that gets added to the customer&#39;s card statement as part of the statement description.  Note that the &#x60;statement_description_identifier&#x60; might get truncated on the statement description to fit the required information including the Square identifier (SQ *) and the name of the seller taking the payment. | [optional] [beta]
**receipt_number** | **String** | The payment&#39;s receipt number. The field is missing if a payment is canceled. | [optional] 
**receipt_url** | **String** | The URL for the payment&#39;s receipt. The field is only populated for COMPLETED payments. | [optional] 


